pub struct PaymentRequest {
pub amount_cents: i64,
pub cash_register_id: Option<String>,
pub payment_type: Option<PaymentCardType>,
pub card_already_present: Option<bool>,
pub receipt_text: Option<String>,
pub tokenization: Option<TokenizationRequest>,
}Expand description
Payment / extended-payment / pre-auth request.
Fields
amount_cents: i64Amount in cents.
cash_register_id: Option<String>Overrides the configured cash-register id when set.
payment_type: Option<PaymentCardType>Requested card handling.
card_already_present: Option<bool>Start with the card already inserted in the terminal.
receipt_text: Option<String>Text printed at the end of the receipt (max 128 chars).
tokenization: Option<TokenizationRequest>Attach tokenization additional data (U) to this transaction.